[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- ewa: ewa splices MP3s according to rules.
  - ewa._ruletab
  - ewa.audio: This module is responsible for managing audio files:
  - ewa.buffutil
  - ewa.clisupport
  - ewa.config: A barebones config object loaded from a Python config file.
  - ewa.frameinfo: find mp3 frame length
  - ewa.lighttpd_hack_middleware
  - ewa.logutil
  - ewa.mp3
  - ewa.ply
    - ewa.ply.cpp
    - ewa.ply.ctokens
    - ewa.ply.lex
    - ewa.ply.yacc
  - ewa.ruleparser: A parser for the rule configuration format.
  - ewa.rules: a rule system for ewa, used to determine what files should appear before or after a main mp3 file in a composite mp3.
  - ewa.transcode
  - ewa.wsgiapp: A WSGI application that generates mp3s dynamically according to a ruleset.